==> open-xchange-core_6.22.0.orig.tar.bz2: open-xchange-core-6.22.0/com.openexchange.server/src/com/openexchange/cache/impl/QueryCacheKey.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.cache.impl;

import java.io.Serializable;

/**
 * QueryCacheKey
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
public class QueryCacheKey implements Serializable {

	private static final long serialVersionUID = -8531547389903446885L;

	public static enum Module {

		FOLDER(1);

		private int num;

		private Module(final int num) {
			this.num = num;
		}

		public int getNum() {
			return num;
		}
	}

	private final int cid;

	private final int userId;

	private final Module module;

	private final int queryNum;

	private final int hash;

	/**
     * Constructor
     */
	public QueryCacheKey(final int cid, final int userId, final Module module, final int queryNum) {
		super();
		this.cid = cid;
		this.userId = userId;
		this.module = module;
		this.queryNum = queryNum;
		hash = queryNum ^ (module.getNum() ^ (userId ^ cid));
	}

	@Override
	public boolean equals(final Object obj) {
		if (!(obj instanceof QueryCacheKey)) {
			return false;
		}
		final QueryCacheKey other = (QueryCacheKey) obj;
		return (this.cid == other.cid) && (this.userId == other.userId) && (this.module.num == other.module.num)
				&& (this.queryNum == other.queryNum);
	}

	@Override
	public int hashCode() {
		return hash;
	}

	@Override
	public String toString() {
		return new StringBuilder(50).append("QueryCacheKey context=").append(cid).append(" | userId=").append(userId)
				.append(" | module=").append(module.num).append(" | queryNum=").append(queryNum).toString();
	}

}

==> open-xchange-core_7.4.2.orig.tar.bz2: open-xchange-core-7.4.2/com.openexchange.server/src/com/openexchange/cache/impl/QueryCacheKey.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.cache.impl;

import java.io.Serializable;

/**
 * QueryCacheKey
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
public class QueryCacheKey implements Serializable {

	private static final long serialVersionUID = -8531547389903446885L;

	public static enum Module {

		FOLDER(1);

		private int num;

		private Module(final int num) {
			this.num = num;
		}

		public int getNum() {
			return num;
		}
	}

	private final int cid;

	private final int userId;

	private final Module module;

	private final int queryNum;

	private final int hash;

	/**
     * Constructor
     */
	public QueryCacheKey(final int cid, final int userId, final Module module, final int queryNum) {
		super();
		this.cid = cid;
		this.userId = userId;
		this.module = module;
		this.queryNum = queryNum;
		hash = queryNum ^ (module.getNum() ^ (userId ^ cid));
	}

	@Override
	public boolean equals(final Object obj) {
		if (!(obj instanceof QueryCacheKey)) {
			return false;
		}
		final QueryCacheKey other = (QueryCacheKey) obj;
		return (this.cid == other.cid) && (this.userId == other.userId) && (this.module.num == other.module.num)
				&& (this.queryNum == other.queryNum);
	}

	@Override
	public int hashCode() {
		return hash;
	}

	@Override
	public String toString() {
		return new com.openexchange.java.StringAllocator(50).append("QueryCacheKey context=").append(cid).append(" | userId=").append(userId)
				.append(" | module=").append(module.num).append(" | queryNum=").append(queryNum).toString();
	}

}
